==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfPageCountField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPageCountField(PdfSingleValueField):
    """
    Represents total page count automatic field.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfPageCountField class.
        """
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountField.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageCountField_CreatePdfPageCountField()
        super(PdfPageCountField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfPageCountField class with the specified font.
        
        Args:
            font (PdfFontBase): The font to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldF(ptrFont)
        super(PdfPageCountField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfPageCountField class with the specified font and brush.
        
        Args:
            font (PdfFontBase): The font to use for the field.
            brush (PdfBrush): The brush to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFB(ptrFont, ptrBrush)
        super(PdfPageCountField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfPageCountField class with the specified font and bounds.
        
        Args:
            font (PdfFontBase): The font to use for the field.
            bounds (RectangleF): The bounds of the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFBs.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFBs(ptrFont, ptrBounds)
        super(PdfPageCountField, self).__init__(intPtr)

    @property
    def NumberStyle(self) -> 'PdfNumberStyle':
        """
        Gets or sets the number style.
        
        Returns:
            PdfNumberStyle: The number style.
        """
        GetDllLibPdf().PdfPageCountField_get_NumberStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageCountField_get_NumberStyle.restype = c_int
        ret = GetDllLibPdf().PdfPageCountField_get_NumberStyle(self.Ptr)
        objwrapped = PdfNumberStyle(ret)
        return objwrapped

    @NumberStyle.setter
    def NumberStyle(self, value: 'PdfNumberStyle'):
        """
        Sets the number style.
        
        Args:
            value (PdfNumberStyle): The number style to set.
        """
        GetDllLibPdf().PdfPageCountField_set_NumberStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfPageCountField_set_NumberStyle(self.Ptr, value.value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfPageCountField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPageCountField(PdfSingleValueField):
    """
    Represents total page count automatic field.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfPageCountField class.
        """
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountField.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageCountField_CreatePdfPageCountField)
        super(PdfPageCountField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfPageCountField class with the specified font.
        
        Args:
            font (PdfFontBase): The font to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldF,ptrFont)
        super(PdfPageCountField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfPageCountField class with the specified font and brush.
        
        Args:
            font (PdfFontBase): The font to use for the field.
            brush (PdfBrush): The brush to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFB.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFB,ptrFont, ptrBrush)
        super(PdfPageCountField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfPageCountField class with the specified font and bounds.
        
        Args:
            font (PdfFontBase): The font to use for the field.
            bounds (RectangleF): The bounds of the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFBs.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageCountField_CreatePdfPageCountFieldFBs,ptrFont, ptrBounds)
        super(PdfPageCountField, self).__init__(intPtr)

    @property
    def NumberStyle(self) -> 'PdfNumberStyle':
        """
        Gets or sets the number style.
        
        Returns:
            PdfNumberStyle: The number style.
        """
        GetDllLibPdf().PdfPageCountField_get_NumberStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageCountField_get_NumberStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageCountField_get_NumberStyle,self.Ptr)
        objwrapped = PdfNumberStyle(ret)
        return objwrapped

    @NumberStyle.setter
    def NumberStyle(self, value: 'PdfNumberStyle'):
        """
        Sets the number style.
        
        Args:
            value (PdfNumberStyle): The number style to set.
        """
        GetDllLibPdf().PdfPageCountField_set_NumberStyle.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageCountField_set_NumberStyle,self.Ptr, value.value)
